package com.loafle.overflow.model.sensor;

import com.loafle.overflow.model.meta.MetaCrawlerMapping;
import com.loafle.overflow.model.meta.MetaDisplayItem;
import com.loafle.overflow.model.meta.MetaSensorStatus;
import com.loafle.overflow.model.target.Target;
import org.hibernate.annotations.OnDelete;
import org.hibernate.annotations.OnDeleteAction;

import javax.persistence.*;
import java.util.Date;
import java.util.List;

/**
 * Created by root on 17. 6. 22.
 */
@Entity
@Table(name = "SENSOR", schema = "public")
public class Sensor {

  @Id
  @GeneratedValue(strategy = GenerationType.IDENTITY)
  private Long id;

  @ManyToOne
  @OnDelete(action = OnDeleteAction.CASCADE)
  @JoinColumn(name = "TARGET_ID", nullable = false)
  private Target target;

  @Column(name = "NAME", nullable = false, length = 50)
  private String name;

  @ManyToOne
  @JoinColumn(name = "META_SENSOR_STATUS_ID")
  private MetaSensorStatus metaSensorStatus;

  @ManyToOne
  @JoinColumn(name = "META_CRAWLER_MAPPING_ID", nullable = false)
  private MetaCrawlerMapping metaCrawlerMapping;

  @Column(name = "CRAWLER_INPUT_ITEMS", nullable = true, length = 50)
  private String crawlerInputItems;

  @Column(name = "ITEM_COUNT", nullable = false)
  private Integer itemCount = 0;

  @Temporal(TemporalType.TIMESTAMP)
  @Column(name = "CREATE_DATE", nullable = false, columnDefinition = "TIMESTAMP DEFAULT CURRENT_TIMESTAMP", insertable = false, updatable = false)
  private Date createDate;

  @Transient
  private List<MetaDisplayItem> sensorItems;

  public Long getId() {
    return id;
  }

  public void setId(Long id) {
    this.id = id;
  }

  public MetaSensorStatus getMetaSensorStatus() {
    return metaSensorStatus;
  }

  public void setMetaSensorStatus(MetaSensorStatus metaSensorStatus) {
    this.metaSensorStatus = metaSensorStatus;
  }

  public Target getTarget() {
    return target;
  }

  public void setTarget(Target target) {
    this.target = target;
  }

  public MetaCrawlerMapping getMetaCrawlerMapping() {
    return metaCrawlerMapping;
  }

  public void setMetaCrawlerMapping(MetaCrawlerMapping metaCrawlerMapping) {
    this.metaCrawlerMapping = metaCrawlerMapping;
  }

  public String getCrawlerInputItems() {
    return crawlerInputItems;
  }

  public void setCrawlerInputItems(String crawlerInputItems) {
    this.crawlerInputItems = crawlerInputItems;
  }

  public Integer getItemCount() {
    return itemCount;
  }

  public void setItemCount(Integer itemCount) {
    this.itemCount = itemCount;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public Date getCreateDate() {
    return createDate;
  }

  public void setCreateDate(Date createDate) {
    this.createDate = createDate;
  }

  public List<MetaDisplayItem> getSensorItems() {
    return sensorItems;
  }

  public void setSensorItems(List<MetaDisplayItem> sensorItems) {
    this.sensorItems = sensorItems;
  }

  @PrePersist
  void preInsert() {
    this.itemCount = 0;
  }

}
